==> org.opennms.features.topology.app-19.0.0-20160722.043226-46-sources.jar: org/opennms/features/topology/app/internal/gwt/client/service/filter/EqFilter.java <==
/*******************************************************************************
 * This file is part of OpenNMS(R).
 *
 * Copyright (C) 2012-2014 The OpenNMS Group, Inc.
 * OpenNMS(R) is Copyright (C) 1999-2014 The OpenNMS Group, Inc.
 *
 * OpenNMS(R) is a registered trademark of The OpenNMS Group, Inc.
 *
 * OpenNMS(R) is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published
 * by the Free Software Foundation, either version 3 of the License,
 * or (at your option) any later version.
 *
 * OpenNMS(R) is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with OpenNMS(R).  If not, see:
 *      http://www.gnu.org/licenses/
 *
 * For more information contact:
 *     OpenNMS(R) Licensing <license@opennms.org>
 *     http://www.opennms.org/
 *     http://www.opennms.com/
 *******************************************************************************/

package org.opennms.features.topology.app.internal.gwt.client.service.filter;

public class EqFilter extends AttributeComparisonFilter {

    private String m_value;

    public EqFilter(String attribute, String value) {
        super(attribute);
        m_value = value;
    }
    
    

    @Override
    protected boolean valueMatches(String value) {
        return m_value.equals(value);
    }

    @Override
    public String toString() {
        StringBuilder buf = new StringBuilder();
        buf.append("(");
        buf.append(getAttribute());
        buf.append("=");
        buf.append(escaped(m_value));
        buf.append(")");
        return buf.toString();
        
    }
    
    private String escaped(String value) {
        return value
            .replace("\\", "\\\\")
            .replace("*", "\\*")
            .replace(")", "\\)")
            .replace("(", "\\(")
            ;
    }

}

==> org.opennms.features.topology.app-21.1.0-20190523.191543-68-sources.jar: org/opennms/features/topology/app/internal/gwt/client/service/filter/EqFilter.java <==
/*******************************************************************************
 * This file is part of OpenNMS(R).
 *
 * Copyright (C) 2012-2014 The OpenNMS Group, Inc.
 * OpenNMS(R) is Copyright (C) 1999-2014 The OpenNMS Group, Inc.
 *
 * OpenNMS(R) is a registered trademark of The OpenNMS Group, Inc.
 *
 * OpenNMS(R) is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published
 * by the Free Software Foundation, either version 3 of the License,
 * or (at your option) any later version.
 *
 * OpenNMS(R) is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with OpenNMS(R).  If not, see:
 *      http://www.gnu.org/licenses/
 *
 * For more information contact:
 *     OpenNMS(R) Licensing <license@opennms.org>
 *     http://www.opennms.org/
 *     http://www.opennms.com/
 *******************************************************************************/

package org.opennms.features.topology.app.internal.gwt.client.service.filter;

public class EqFilter extends AttributeComparisonFilter {

    private String m_value;

    public EqFilter(String attribute, String value) {
        super(attribute);
        m_value = value;
    }
    
    

    @Override
    protected boolean valueMatches(String value) {
        return m_value.equals(value);
    }

    @Override
    public String toString() {
        final StringBuilder buf = new StringBuilder();
        buf.append("(");
        buf.append(getAttribute());
        buf.append("=");
        buf.append(escaped(m_value));
        buf.append(")");
        return buf.toString();
        
    }
    
    private String escaped(String value) {
        return value
            .replace("\\", "\\\\")
            .replace("*", "\\*")
            .replace(")", "\\)")
            .replace("(", "\\(")
            ;
    }

}
